%global rust_toolchain_version 1.80.1

Name:       nushell
Version:    0.104.0
Release:    1%{?dist}
Summary:    A new type of shell

License:    MIT
URL:        https://github.com/nushell/nushell
Source:     %{url}/archive/%{version}/%{name}-%{version}.tar.gz

%if 0%{?el8} || 0%{?el9}
%else
BuildRequires: cargo >= %{rust_toolchain_version}
BuildRequires: rust >= %{rust_toolchain_version}
%endif
BuildRequires: gcc
BuildRequires: git-core
BuildRequires: python3-devel

BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xcb)
BuildRequires: pkgconfig(zlib)

%description
Nu draws inspiration from projects like PowerShell, functional programming
languages, and modern CLI tools. Rather than thinking of files and data as raw
streams of text, Nu looks at each input as something with structure. For
example, when you list the contents of a directory what you get back is a
table of rows, where each row represents an item in that directory. These
values can be piped through a series of steps, in a series of commands called
a 'pipeline'.


%prep
%autosetup
# Change default optimizations
sed -i '/profile.release/d' Cargo.toml
sed -i '/opt-level =/d' Cargo.toml
sed -i '/strip = "debuginfo"/d' Cargo.toml
sed -i '/lto = "thin"/d' Cargo.toml

echo -e '\n[profile.release]' >> Cargo.toml
echo 'opt-level = "s"  # Optimize for size.' >> Cargo.toml
echo 'strip = "debuginfo"' >> Cargo.toml
echo 'lto = "thin"' >> Cargo.toml
echo 'codegen-units = 1' >> Cargo.toml
# echo 'lto = "fat"' >> Cargo.toml  # Do not enable for Copr build

%if 0%{?el8} || 0%{?el9}
  curl https://sh.rustup.rs -sSf | sh -s -- --profile minimal -y
%endif


%install
# export CARGO_PROFILE_RELEASE_BUILD_OVERRIDE_OPT_LEVEL=3
%if 0%{?el8} || 0%{?el9}
source "$HOME/.cargo/env"
%endif
cargo install --root=%{buildroot}%{_prefix} --path=.

rm -f %{buildroot}%{_prefix}/.crates.toml \
    %{buildroot}%{_prefix}/.crates2.json
strip --strip-all %{buildroot}%{_bindir}/*


%files
%license LICENSE
%doc README.md
%{_bindir}/nu


%changelog
* Wed Apr 30 2025 Artem Polishchuk <ego.cordatus@gmail.com> - 0.104.0-1
- chore: Update to latest release

* Wed Mar 19 2025 Artem Polishchuk <ego.cordatus@gmail.com> - 0.103.0-1
- chore: Update to latest release

* Wed Feb 05 2025 Artem Polishchuk <ego.cordatus@gmail.com> - 0.102.0-1
- chore: Update to latest release

* Sun Dec 22 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.101.0-1
- chore: Update to latest release

* Wed Nov 13 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.100.0-1
- chore: Update to latest release

* Mon Oct 21 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.99.1-1
- chore: Update to latest release

* Wed Oct 16 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.99.0-1
- chore: Update to latest release

* Wed Sep 18 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.98.0-1
- chore: Update to latest release

* Thu Aug 01 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.96.1-1
- chore: Update to latest release

* Wed Jul 24 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.96.0-1
- chore: Update to latest release

* Wed Jun 26 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.95.0-1
- chore: Update to latest release

* Mon Jun 03 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.94.2-1
- chore: Update to latest release

* Fri May 31 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.94.1-1
- chore: Update to latest release

* Wed May 01 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.93.0-1
- chore: Update to latest release

* Fri Apr 12 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.92.2-1
- chore: Update to latest release

* Thu Apr 04 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.92.1-1
- chore: Update to latest release

* Tue Apr 02 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.92.0-1
- chore: Update to latest release

* Wed Mar 06 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.91.0-1
- chore: Update to latest release

* Wed Feb 07 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.90.1-1
- chore: Update to latest release

* Tue Jan 09 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.89.0-1
- chore: Update to latest release

* Thu Dec 14 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.88.1-1
- chore: Update to latest release

* Tue Dec 12 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.88.0-1
- chore: Update to latest release

* Mon Nov 20 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.87.1-1
- chore: Update to latest release

* Wed Nov 15 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.87.0-1
- chore: Update to latest release

* Tue Oct 17 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.86.0-1
- chore: Update to latest release

* Wed Sep 20 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.85.0-1
- chore(update): 0.85.0

* Wed Aug 23 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.84.0-1
- chore(update): 0.84.0

* Sun Jul 30 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.83.1-1
- chore(update): 0.83.1

* Tue Jul 25 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.83.0-1
- chore(update): 0.83.0

* Tue Jun 27 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.82.0-1
- chore(update): 0.82.0

* Wed Jun 07 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.81.0-1
- chore(update): 0.81.0

* Wed May 17 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.80.0-1
- chore(update): 0.80.0

* Wed Apr 26 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.79.0-1
- chore(update): 0.79.0

* Wed Apr 05 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.78.0-1
- chore(update): 0.78.0

* Fri Mar 17 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.77.1-1
- chore(update): 0.77.1

* Tue Mar 14 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.77.0-1
- chore(update): 0.77.0

* Tue Feb 21 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.76.0-1
- chore(update): 0.76.0

* Wed Feb 01 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.75.0-1
- chore(update): 0.75.0

* Wed Dec 21 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.73.0-1
- chore(update): 0.73.0

* Mon Dec 05 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.72.1-1
- chore(update): 0.72.1

* Wed Nov 30 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.72.0-1
- chore(update): 0.72.0

* Wed Nov 09 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.71.0-1
- chore(update): 0.71.0

* Wed Oct 19 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.70.0-1
- chore(update): 0.70.0

* Wed Sep 28 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.69.1-1
- chore(update): 0.69.1

* Fri Sep 09 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.68.1-1
- chore(update): 0.68.1

* Wed Aug 17 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.67.0-1
- chore(update): 0.67.0

* Sun Jul 31 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.66.2-1
- chore(update): 0.66.2

* Thu Jul 28 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.66.1-1
- chore(update): 0.66.1

* Wed Jul 27 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.66.0-1
- chore(update): 0.66.0

* Tue Jun 21 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.64.0-1
- chore(update): 0.64.0

* Wed May 25 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.63.0-1
- chore(update): 0.63.0

* Wed May 04 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.62.0-2
- build: Build with system openssl

* Tue May 03 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.62.0-1
- chore(update): 0.62.0

* Wed Apr 13 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.61.0-1
- chore(update): 0.61.0

* Wed Mar 23 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.60.0-1
- chore(update): 0.60.0

* Wed Feb 09 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.44.0-4
- build: With codegen-units = 1

* Tue Feb 08 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.44.0-2
- build: With --features=extra

* Tue Feb 08 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.44.0-1
- chore(update): 0.44.0

* Tue Jan 18 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.43.0-1
- chore(update): 0.43.0

* Thu Dec 30 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.42.0-1
- chore(update): 0.42.0

* Fri Dec 10 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.41.0-1
- chore(update): 0.41.0

* Fri Nov 19 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.40.0-1
- chore(update): 0.40.0

* Wed Oct 27 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.39.0-1
- chore(update): 0.39.0

* Wed Sep 15 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.37.0-1
- build(update): 0.37.0

* Wed Jul 14 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.34.0-1
- build(update): 0.34.0

* Tue Jun 22 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.33.0-1
- build(update): 0.33.0

* Wed Jun 02 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.32.0-1
- build(update): 0.32.0

* Tue May 11 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.31.0-1
- build(update): 0.31.0

* Wed Apr 21 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.30.0-1
- build(update): 0.30.0

* Tue Mar 30 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.29.0-1
- build(update): 0.29.0

* Tue Mar 09 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.28.0-1
- build(update): 0.28.0

* Fri Feb 19 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.27.1-1
- build(update): 0.27.1

* Tue Feb 16 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.27.0-1
- build(update): 0.27.0

* Wed Jan 27 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.26.0-1
- build(update): 0.26.0

* Wed Jan  6 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.25.1-1
- build(update): 0.25.1

* Tue Jan  5 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.25.0-1
- build(update): 0.25.0

* Wed Dec 16 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.24.1-1
- build(update): 0.24.1

* Wed Nov 25 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.23.0-1
- build(update): 0.23.0

* Tue Nov  3 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.22.0-1
- Update to 0.22.0

* Wed Oct 14 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.21.0-1
- build(update): 0.21.0

* Tue Sep 22 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.20.0-1
- Update to 0.20.0

* Wed Sep  2 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.19.0-1
- Update to 0.19.0

* Wed Aug 12 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.18.1-1
- Update to 0.18.1

* Wed Jul 22 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.17.0-1
- Update to 0.17.0

* Wed Jul 01 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.16.0-1
- Update to 0.16.0

* Tue Jun 09 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.15.0-1
- Update to 0.15.0

* Sat May 23 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.14.0-2
- Built with codegen-units = 1

* Tue May 12 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.14.0-1
- Update to 0.14.0

* Tue Apr 21 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.13.0-1
- Update to 0.13.0

* Tue Mar 31 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.12.0-1
- Update to 0.12.0

* Wed Mar 11 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.11.0-1
- Update to 0.11.0

* Wed Feb 19 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.10.0-1
- Update to 0.10.0

* Wed Jan 29 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.9.0-1
- Update to 0.9.0

* Tue Jan 07 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.8.0-1
- Update to 0.8.0

* Thu Dec 19 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.7.0-2
- Build with only Stable features

* Wed Dec 18 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.7.0-1
- Update to 0.7.0

* Wed Dec 18 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.6.1-2
- Build with all features. Thanks to Dennis Schridde.

* Sun Dec 01 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.6.1-1
- Update to 0.6.1

* Wed Nov 27 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.6.0-1
- Update to 0.6.0

* Fri Nov 08 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.0-2.20191106git01d6287
- Switch to system Rust 1.39

* Wed Nov 06 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.0-1.20191106git01d6287
- Update to 0.5.0

* Thu Aug 29 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.2.0-1.20190727git65ed458
- Initial package
